From 69cd023e061187de774df5cd4b8eed1e59d6de49 Mon Sep 17 00:00:00 2001
From: Andres Freund <andres@anarazel.de>
Date: Mon, 26 Sep 2022 11:31:32 -0700
Subject: [PATCH v17 03/23] meson: Include CFLAGS/c_args in summary and
 pg_config output

Previously arguments passed in via CFLAGS/-Dc_args were neither displayed in
meson's summary, nor in pg_config's output.

Reported-by: "wangw.fnst@fujitsu.com" <wangw.fnst@fujitsu.com>
Discussion: https://postgr.es/m/OS3PR01MB62751847BC9CD2DB7B29AC129E529@OS3PR01MB6275.jpnprd01.prod.outlook.com
---
 src/include/meson.build | 10 +++++++---
 meson.build             |  4 ++++
 2 files changed, 11 insertions(+), 3 deletions(-)

diff --git a/src/include/meson.build b/src/include/meson.build
index e5390df0584..f2f7d03ff27 100644
--- a/src/include/meson.build
+++ b/src/include/meson.build
@@ -42,11 +42,15 @@ config_paths_data.set_quoted('MANDIR', dir_prefix / dir_man)
 
 var_cc = ' '.join(cc.cmd_array())
 var_cpp = ' '.join(cc.cmd_array() + ['-E'])
-var_cflags = ' '.join(cflags + cflags_warn)
-var_cxxflags = ' '.join(cxxflags + cxxflags_warn)
+var_cflags = ' '.join(cflags + cflags_warn + get_option('c_args'))
+if llvm.found()
+  var_cxxflags = ' '.join(cxxflags + cxxflags_warn + get_option('cpp_args'))
+else
+  var_cxxflags = ''
+endif
 var_cppflags = ' '.join(cppflags)
 var_cflags_sl = '-fPIC' #FIXME
-var_ldflags = ' '.join(ldflags)
+var_ldflags = ' '.join(ldflags + get_option('c_link_args'))
 var_ldflags_sl = ''.join(ldflags_sl)
 var_ldflags_ex = '' # FIXME
 # FIXME - some extensions might directly use symbols from one of libs. If
diff --git a/meson.build b/meson.build
index 6ffae59ba03..474a42a2559 100644
--- a/meson.build
+++ b/meson.build
@@ -2966,6 +2966,9 @@ if meson.version().version_compare('>=0.57')
       'CPP FLAGS': ' '.join(cppflags),
       'C FLAGS, functional': ' '.join(cflags),
       'C FLAGS, warnings': ' '.join(cflags_warn),
+      'C FLAGS, modules': ' '.join(cflags_mod),
+      'C FLAGS, user specified': ' '.join(get_option('c_args')),
+      'LD FLAGS': ' '.join(ldflags + get_option('c_link_args')),
     },
     section: 'Compiler Flags',
   )
@@ -2982,6 +2985,7 @@ if meson.version().version_compare('>=0.57')
       {
         'C++ FLAGS, functional': ' '.join(cxxflags),
         'C++ FLAGS, warnings': ' '.join(cxxflags_warn),
+        'C++ FLAGS, user specified': ' '.join(get_option('cpp_args')),
       },
       section: 'Compiler Flags',
     )
-- 
2.37.3.542.gdd3f6c4cae

